@@ -62,13 +62,13 @@ class SoloMotorController:
 
     def __init__(
         self,
+        port="/dev/ttyS0",
         address=0,
         baudrate=937500,
-        port="/dev/ttyS0",
         timeout=3,
         loggerLevel=logging.INFO):
 
-        self._version = "SoloPy v2.1"
+        self._version = "SoloPy v2.5"
         
         # logger init
         logging.shutdown()
@@ -344,7 +344,7 @@ class SoloMotorController:
         return status
         
     def serial_is_working(self) -> bool:
-        if(self.get_voltage_a() == -1):
+        if(self.get_phase_a_voltage() == -1):
             return False
         return True
 
